FermiHandler
========================

The :func:`pyprocar.scripts.FermiHandler` is used to plot the 2d band structure

.. autosummary::
   :toctree: _autosummary

   pyprocar.scripts.FermiHandler

.. seealso::
   :doc:`/api/cfg/fermi_surface_3d`